@@ -7,6 +7,11 @@ from thorium.fields import CharField
 from thorium.validators import CharValidator
 
 
+# Add transifex translate attribute
+for attr_list in WHITELIST.values():
+    attr_list.append('translate')
+
+
 class HTMLValidator(CharValidator):
 
     purifier = HTMLPurifier(WHITELIST, validate=True)
